@@ -1,23 +1,11 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2001,2002 Ellis Whitehead <ellis@kde.org>
-    Copyright (C) 2006 Hamish Rodda <rodda@kde.org>
-    Copyright (C) 2007 Andreas Hartmetz <ahartmetz@gmail.com>
-    Copyright (C) 2008 Michael Jansen <kde@michael-jansen.biz>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2001, 2002 Ellis Whitehead <ellis@kde.org>
+    SPDX-FileCopyrightText: 2006 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2007 Andreas Hartmetz <ahartmetz@gmail.com>
+    SPDX-FileCopyrightText: 2008 Michael Jansen <kde@michael-jansen.biz>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kglobalaccel.h"
@@ -27,11 +15,10 @@
 #include <memory>
 
 #include <QAction>
-#include <QActionEvent>
 #include <QGuiApplication>
 #include <QMessageBox>
 #include <QPushButton>
-#include <QDBusInterface>
+#include <QDBusMessage>
 #include <QDBusMetaType>
 #include <config-kglobalaccel.h>
 #if HAVE_X11
@@ -116,7 +103,7 @@ void KGlobalAccelPrivate::cleanup()
 
 KGlobalAccelPrivate::KGlobalAccelPrivate(KGlobalAccel *q)
     :
-#ifndef KGLOBALACCEL_NO_DEPRECATED
+#if KGLOBALACCEL_BUILD_DEPRECATED_SINCE(4, 4)
     enabled(true),
 #endif
     q(q),
@@ -194,7 +181,7 @@ bool KGlobalAccel::isComponentActive(const QString &componentUnique)
     return component->isActive();
 }
 
-#ifndef KGLOBALACCEL_NO_DEPRECATED
+#if KGLOBALACCEL_BUILD_DEPRECATED_SINCE(4, 4)
 bool KGlobalAccel::isEnabled() const
 {
     return d->enabled;
@@ -206,7 +193,7 @@ org::kde::kglobalaccel::Component *KGlobalAccel::getComponent(const QString &com
     return d->getComponent(componentUnique);
 }
 
-#ifndef KGLOBALACCEL_NO_DEPRECATED
+#if KGLOBALACCEL_BUILD_DEPRECATED_SINCE(4, 4)
 void KGlobalAccel::setEnabled(bool enabled)
 {
     d->enabled = enabled;
@@ -250,7 +237,7 @@ bool KGlobalAccelPrivate::doRegister(QAction *action)
 
     QStringList actionId = makeActionId(action);
 
-    nameToAction.insertMulti(actionId.at(KGlobalAccel::ActionUnique), action);
+    nameToAction.insert(actionId.at(KGlobalAccel::ActionUnique), action);
     actions.insert(action);
     iface()->doRegister(actionId);
 
@@ -282,15 +269,20 @@ void KGlobalAccelPrivate::remove(QAction *action, Removal removal)
     if (removal == UnRegister) {
         // Complete removal of the shortcut is requested
         // (forgetGlobalShortcut)
-        iface()->unRegister(actionId);
+        unregister(actionId);
     } else {
         // If the action is a configurationAction wen only remove it from our
         // internal registry. That happened above.
+
+        // If we are merely marking a callback as inactive there is nothing for kglobalaccel to do if kglobalaccel is not running
+        // this can happen on shutdown where all apps and kglobalaccel are all torn down at once
+        // For this reason we turn off the autostart flag in the DBus message call
+
         if (!action->property("isConfigurationAction").toBool()) {
             // If it's a session shortcut unregister it.
-            action->objectName().startsWith(QStringLiteral("_k_session:"))
-            ? iface()->unRegister(actionId)
-            : iface()->setInactive(actionId);
+            action->objectName().startsWith(QLatin1String("_k_session:"))
+            ? unregister(actionId)
+            : setInactive(actionId);
         }
     }
 
@@ -298,6 +290,22 @@ void KGlobalAccelPrivate::remove(QAction *action, Removal removal)
     actionShortcuts.remove(action);
 }
 
+void KGlobalAccelPrivate::unregister(const QStringList &actionId)
+{
+    auto message = QDBusMessage::createMethodCall(iface()->service(), iface()->path(), iface()->interface(), QStringLiteral("unRegister"));
+    message.setArguments({actionId});
+    message.setAutoStartService(false);
+    QDBusConnection::sessionBus().call(message, QDBus::NoBlock);
+}
+
+void KGlobalAccelPrivate::setInactive(const QStringList &actionId)
+{
+    auto message = QDBusMessage::createMethodCall(iface()->service(), iface()->path(), iface()->interface(), QStringLiteral("setInactive"));
+    message.setArguments({actionId});
+    message.setAutoStartService(false);
+    QDBusConnection::sessionBus().call(message, QDBus::NoBlock);
+}
+
 void KGlobalAccelPrivate::updateGlobalShortcut(/*const would be better*/QAction* action,
                                                ShortcutTypes actionFlags,
                                                KGlobalAccel::GlobalShortcutLoading globalFlags)
@@ -513,14 +521,14 @@ void KGlobalAccelPrivate::reRegisterAll()
     }
 }
 
-#ifndef KGLOBALACCEL_NO_DEPRECATED
+#if KGLOBALACCEL_BUILD_DEPRECATED_SINCE(4, 2)
 QList<QStringList> KGlobalAccel::allMainComponents()
 {
     return d->iface()->allMainComponents();
 }
 #endif
 
-#ifndef KGLOBALACCEL_NO_DEPRECATED
+#if KGLOBALACCEL_BUILD_DEPRECATED_SINCE(4, 2)
 QList<QStringList> KGlobalAccel::allActionsForComponent(const QStringList &actionId)
 {
     return d->iface()->allActionsForComponent(actionId);
@@ -528,7 +536,7 @@ QList<QStringList> KGlobalAccel::allActionsForComponent(const QStringList &actio
 #endif
 
 //static
-#ifndef KGLOBALACCEL_NO_DEPRECATED
+#if KGLOBALACCEL_BUILD_DEPRECATED_SINCE(4, 2)
 QStringList KGlobalAccel::findActionNameSystemwide(const QKeySequence &seq)
 {
     return self()->d->iface()->action(seq[0]);
@@ -546,7 +554,7 @@ bool KGlobalAccel::isGlobalShortcutAvailable(const QKeySequence &seq, const QStr
 }
 
 //static
-#ifndef KGLOBALACCEL_NO_DEPRECATED
+#if KGLOBALACCEL_BUILD_DEPRECATED_SINCE(4, 2)
 bool KGlobalAccel::promptStealShortcutSystemwide(QWidget *parent, const QStringList &actionIdentifier,
         const QKeySequence &seq)
 {
@@ -705,10 +713,12 @@ bool KGlobalAccel::hasShortcut(const QAction *action) const
     return d->actionShortcuts.contains(action) || d->actionDefaultShortcuts.contains(action);
 }
 
+#if KGLOBALACCEL_BUILD_DEPRECATED_SINCE(5, 9)
 bool KGlobalAccel::eventFilter(QObject *watched, QEvent *event)
 {
     return QObject::eventFilter(watched, event);
 }
+#endif
 
 bool KGlobalAccel::setGlobalShortcut(QAction *action, const QList<QKeySequence> &shortcut)
 {
