@@ -1,23 +1,10 @@
 /*
     This file is part of the KDE libraries
 
-    Copyright (c) 2007 Andreas Hartmetz <ahartmetz@gmail.com>
-    Copyright (c) 2007 Michael Jansen <kde@michael-jansen.biz>
+    SPDX-FileCopyrightText: 2007 Andreas Hartmetz <ahartmetz@gmail.com>
+    SPDX-FileCopyrightText: 2007 Michael Jansen <kde@michael-jansen.biz>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kglobalacceld.h"
@@ -35,7 +22,6 @@
 #include <QDBusObjectPath>
 
 #include "kglobalaccel.h"
-#include <QDebug>
 
 
 struct KGlobalAccelDPrivate
@@ -492,6 +478,7 @@ bool KGlobalAccelD::unregister(const QString &componentUnique, const QString &sh
 }
 
 
+#if KGLOBALACCELPRIVATE_BUILD_DEPRECATED_SINCE(4, 3)
 void KGlobalAccelD::unRegister(const QStringList &actionId)
 {
 #ifdef KDEDGLOBALACCEL_TRACE
@@ -506,7 +493,7 @@ void KGlobalAccelD::unRegister(const QStringList &actionId)
     }
 
 }
-
+#endif
 
 QList<int> KGlobalAccelD::setShortcut(const QStringList &actionId,
                                         const QList<int> &keys, uint flags)
