@@ -1,23 +1,10 @@
 /*
     This file is part of the KDE libraries
 
-    Copyright (c) 2007 Andreas Hartmetz <ahartmetz@gmail.com>
-    Copyright (c) 2008 Michael Jansen <kde@michael-jansen.biz>
+    SPDX-FileCopyrightText: 2007 Andreas Hartmetz <ahartmetz@gmail.com>
+    SPDX-FileCopyrightText: 2008 Michael Jansen <kde@michael-jansen.biz>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #ifndef KGLOBALACCELD_H
 #define KGLOBALACCELD_H
@@ -35,7 +22,7 @@ struct KGlobalAccelDPrivate;
 /**
  * @todo get rid of all of those QStringList parameters.
  */
-class KF5GLOBALACCELPRIVATE_EXPORT KGlobalAccelD : public QObject, protected QDBusContext
+class KGLOBALACCELPRIVATE_EXPORT KGlobalAccelD : public QObject, protected QDBusContext
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.KGlobalAccel")
@@ -52,7 +39,7 @@ public:
     Q_DECLARE_FLAGS(SetShortcutFlags, SetShortcutFlag)
     Q_FLAG(SetShortcutFlags)
 
-    KGlobalAccelD(QObject* parent = nullptr);
+    explicit KGlobalAccelD(QObject* parent = nullptr);
     ~KGlobalAccelD();
 
     bool init();
@@ -100,8 +87,11 @@ public Q_SLOTS:
 
     Q_SCRIPTABLE void doRegister(const QStringList &actionId);
 
-    //! @see unregister
-    Q_SCRIPTABLE QT_DEPRECATED void unRegister(const QStringList &actionId);
+#if KGLOBALACCELPRIVATE_ENABLE_DEPRECATED_SINCE(4, 3)
+    //! @deprecated Since 4.3, use KGlobalAccelD::unregister
+    KGLOBALACCELPRIVATE_DEPRECATED_VERSION(4, 3, "Use KGlobalAccelD::unregister(const QString&, const QString&")
+    Q_SCRIPTABLE void unRegister(const QStringList &actionId);
+#endif
 
     Q_SCRIPTABLE void activateGlobalShortcutContext(
             const QString &component,
